@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2018-2020- Swiss Data Science Center (SDSC)
+# Copyright 2018-2021 - Swiss Data Science Center (SDSC)
 # A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
 # Eidgenössische Technische Hochschule Zürich (ETHZ).
 #
@@ -25,12 +25,13 @@ import attr
 from git import NULL_TREE
 
 from renku.core import errors
-from renku.core.commands.client import pass_local_client
+from renku.core.incubation.command import Command
 from renku.core.models.entities import Collection, Entity
 from renku.core.models.git import Range
 from renku.core.models.provenance.activities import Activity, ProcessRun, Usage, WorkflowRun
 from renku.core.models.provenance.qualified import Generation
 from renku.core.models.workflow.run import Run
+from renku.core.utils.scm import git_unicode_unescape
 
 
 def _safe_path(filepath, can_be_cwl=False):
@@ -52,7 +53,7 @@ def _safe_path(filepath, can_be_cwl=False):
     return True
 
 
-@attr.s(cmp=False)
+@attr.s(eq=False, order=False)
 class Graph(object):
     """Represent the provenance graph."""
 
@@ -271,7 +272,11 @@ class Graph(object):
                         if all(member.path != d.path for d in dependencies) and any(
                             u.startswith(member.path) for u in usage_paths
                         ):
-                            dependencies = [d for d in dependencies if not d.path.startswith(member.path)]
+                            dependencies = [
+                                d
+                                for d in dependencies
+                                if not (self.client.path / member.path).is_dir() or not d.path.startswith(member.path)
+                            ]
                             dependencies.append(member)
 
         from renku.core.models.sort import topological
@@ -424,7 +429,9 @@ class Graph(object):
             if (node.commit, node.path) not in output_keys:
                 continue
 
-            assert hasattr(node, "activity"), node
+            if not hasattr(node, "activity"):
+                continue
+
             assert isinstance(node.activity, ProcessRun)
 
             plan = node.activity.association.plan
@@ -514,8 +521,7 @@ class Graph(object):
         return run
 
 
-@pass_local_client(requires_migration=True)
-def build_graph(client, revision, no_output, paths):
+def _build_graph(client, revision="HEAD", no_output=False, paths=()):
     """Build graph structure."""
     graph = Graph(client)
     if not paths:
@@ -527,7 +533,7 @@ def build_graph(client, revision, no_output, paths):
 
         commit = client.repo.rev_parse(stop)
         paths = (
-            str(client.path / item.a_path)
+            str(client.path / git_unicode_unescape(item.a_path))
             for item in commit.diff(commit.parents or NULL_TREE)
             # if not item.deleted_file
         )
@@ -535,3 +541,8 @@ def build_graph(client, revision, no_output, paths):
     # NOTE shall we warn when "not no_output and not paths"?
     graph.build(paths=paths, revision=revision, can_be_cwl=no_output)
     return graph
+
+
+def build_graph_command():
+    """Command to build graph structure."""
+    return Command().command(_build_graph).require_migration()
