@@ -19,12 +19,11 @@
 import os
 import shutil
 import urllib
-import uuid
 from pathlib import Path
 
 from renku.core.management.migrations.models.v3 import Dataset, Project, get_client_datasets
 from renku.core.management.repository import DEFAULT_DATA_DIR as DATA_DIR
-from renku.core.models.datasets import generate_dataset_id
+from renku.core.models.datasets import generate_dataset_id, generate_default_name
 from renku.core.models.entities import generate_file_id, generate_label
 from renku.core.models.refs import LinkReference
 from renku.core.utils.migrate import get_pre_0_3_4_datasets_metadata
@@ -56,19 +55,21 @@ def _do_not_track_lock_file(client):
     # Add lock file to .gitignore.
     lock_file = ".renku.lock"
     gitignore = client.path / ".gitignore"
-    if lock_file not in gitignore.read_text():
+    if not gitignore.exists() or lock_file not in gitignore.read_text():
         gitignore.open("a").write("\n{0}\n".format(lock_file))
 
 
 def _migrate_datasets_pre_v0_3(client):
     """Migrate datasets from Renku 0.3.x."""
+    if client.is_using_temporary_datasets_path():
+        return
 
     for old_path in get_pre_0_3_4_datasets_metadata(client):
         name = str(old_path.parent.relative_to(client.path / DATA_DIR))
 
         dataset = Dataset.from_yaml(old_path, client=client)
         dataset.title = name
-        dataset.name = name
+        dataset.name = generate_default_name(name)
         new_path = client.renku_datasets_path / dataset.identifier / client.METADATA
         new_path.parent.mkdir(parents=True, exist_ok=True)
 
@@ -93,27 +94,38 @@ def _migrate_datasets_pre_v0_3(client):
 def _migrate_broken_dataset_paths(client):
     """Ensure all paths are using correct directory structure."""
     for dataset in get_client_datasets(client):
-        expected_path = client.renku_datasets_path / dataset.identifier
         if not dataset.name:
-            dataset.name = dataset.title
+            dataset.name = generate_default_name(dataset.title, dataset.version)
+        else:
+            dataset.name = generate_default_name(dataset.name)
+
+        expected_path = client.renku_datasets_path / dataset.identifier
 
         # migrate the refs
-        ref = LinkReference.create(client=client, name="datasets/{0}".format(dataset.name), force=True,)
-        ref.set_reference(expected_path / client.METADATA)
-
-        old_dataset_path = client.renku_datasets_path / uuid.UUID(dataset.identifier).hex
-
-        dataset.path = os.path.relpath(expected_path, client.path)
+        if not client.is_using_temporary_datasets_path():
+            ref = LinkReference.create(client=client, name="datasets/{0}".format(dataset.name), force=True)
+            ref.set_reference(expected_path / client.METADATA)
 
         if not expected_path.exists():
-            shutil.move(old_dataset_path, expected_path)
+            old_dataset_path = dataset.path
+            if not client.is_using_temporary_datasets_path():
+                expected_path.parent.mkdir(parents=True, exist_ok=True)
+                shutil.move(old_dataset_path, expected_path)
+            else:
+                expected_path.mkdir(parents=True, exist_ok=True)
+                shutil.copy(Path(old_dataset_path) / client.METADATA, expected_path)
+
+        dataset.path = os.path.relpath(expected_path, client.path)
 
         for file_ in dataset.files:
             file_path = Path(file_.path)
             if not file_path.exists() or file_.path.startswith(".."):
-                new_path = Path(
-                    os.path.abspath(client.renku_datasets_path / dataset.identifier / file_path)
-                ).relative_to(client.path)
+                if file_.path.startswith(".."):
+                    new_path = Path(
+                        os.path.abspath(client.renku_datasets_path / dataset.identifier / file_path)
+                    ).relative_to(client.path)
+                else:
+                    new_path = (client.path / DATA_DIR / file_path).relative_to(client.path)
 
                 file_.path = new_path
 
@@ -158,7 +170,8 @@ def _fix_dataset_urls(client):
 def _migrate_dataset_and_files_project(client):
     """Ensure dataset files have correct project."""
     project = Project.from_yaml(client.renku_metadata_path, client)
-    project.to_yaml(client.renku_metadata_path)
+    if not client.is_using_temporary_datasets_path():
+        project.to_yaml(client.renku_metadata_path)
 
     for dataset in get_client_datasets(client):
         dataset._project = project
