@@ -25,6 +25,7 @@ from git import GitError, Repo
 from renku.core import errors
 from renku.core.management.migrations.models.v3 import DatasetFileSchemaV3, get_client_datasets
 from renku.core.models.datasets import DatasetFile, DatasetFileSchema
+from renku.core.models.entities import generate_file_id, generate_label
 from renku.core.utils.urls import remove_credentials
 
 
@@ -35,20 +36,12 @@ def migrate(client):
 
 def _migrate_submodule_based_datasets(client):
     from renku.core.management import LocalClient
-    from renku.core.management.migrate import is_project_unsupported
+    from renku.core.management.migrate import is_project_unsupported, migrate
 
     submodules = client.repo.submodules
     if not submodules:
         return
 
-    for s in submodules:
-        try:
-            s.update()
-        except GitError:
-            pass
-
-    submodules_urls = {s.path: s.url for s in submodules}
-
     repo_paths = []
     symlinks = []
 
@@ -73,11 +66,21 @@ def _migrate_submodule_based_datasets(client):
     if not symlinks:
         return
 
+    for s in submodules:
+        try:
+            s.update()
+        except GitError:
+            pass
+
+    submodules_urls = {s.path: s.url for s in submodules}
+
     remote_clients = {p: LocalClient(p) for p in repo_paths}
 
     for remote_client in remote_clients.values():
         if not is_project_unsupported(remote_client):
-            migrate(remote_client)
+            migrate(
+                remote_client, skip_template_update=True, skip_docker_update=True,
+            )
 
     metadata = {}
 
@@ -129,6 +132,9 @@ def _migrate_submodule_based_datasets(client):
                 based_on, url = metadata[file_.path]
                 file_.based_on = based_on
                 file_.url = remove_credentials(url)
+                file_.commit = client.find_previous_commit(file_.path)
+                file_._id = generate_file_id(client=client, hexsha=file_.commit.hexsha, path=file_.path)
+                file_._label = generate_label(file_.path, file_.commit.hexsha)
 
         dataset.to_yaml()
 
