@@ -35,6 +35,7 @@ from renku.core import errors
 from renku.core.models.provenance.activities import Collection
 from renku.core.models.provenance.datasets import DatasetProvenance
 from renku.core.models.provenance.provenance_graph import ProvenanceGraph
+from renku.core.utils import communication
 from renku.core.utils.file_size import parse_file_size
 from renku.core.utils.git import add_to_git, run_command
 
@@ -153,9 +154,9 @@ class StorageApiMixin(RepositoryApiMixin):
         except (KeyboardInterrupt, OSError) as e:
             raise errors.ParameterError(f"Couldn't run 'git lfs':\n{e}")
 
-    def init_repository(self, force=False, user=None):
+    def init_repository(self, force=False, user=None, initial_branch=None):
         """Initialize a local Renku repository."""
-        result = super().init_repository(force=force, user=user)
+        result = super().init_repository(force=force, user=user, initial_branch=initial_branch)
 
         # initialize LFS if it is requested and installed
         if self.external_storage_requested and self.storage_installed:
@@ -213,8 +214,16 @@ class StorageApiMixin(RepositoryApiMixin):
                     raise errors.GitLFSError(f"Error executing 'git lfs track: \n {result.stdout}")
             except (KeyboardInterrupt, OSError) as e:
                 raise errors.ParameterError(f"Couldn't run 'git lfs':\n{e}")
-            return track_paths
-        return []
+
+        show_message = self.get_value("renku", "show_lfs_message")
+        if track_paths and (show_message is None or show_message == "True"):
+            files_list = "\n\t".join(track_paths)
+            communication.info(
+                f"Adding these files to Git LFS:\n\t{files_list}"
+                "\nTo disable this message in the future, run:\n\trenku config set show_lfs_message False"
+            )
+
+        return track_paths
 
     @check_external_storage_wrapper
     def untrack_paths_from_storage(self, *paths):
