@@ -20,8 +20,6 @@
 import datetime
 import os
 import pathlib
-import re
-import unicodedata
 import uuid
 from pathlib import Path
 from urllib.parse import ParseResult, quote, urljoin, urlparse
@@ -39,6 +37,7 @@ from renku.core.models.provenance.agents import Person, PersonSchema
 from renku.core.models.refs import LinkReference
 from renku.core.utils.datetime8601 import parse_date
 from renku.core.utils.doi import extract_doi, is_doi
+from renku.core.utils.urls import get_slug
 
 NoneType = type(None)
 
@@ -245,8 +244,6 @@ class DatasetFile(Entity):
 
     source = attr.ib(default=None, kw_only=True)
 
-    is_lfs = attr.ib(default=False, kw_only=True)
-
     @added.default
     def _now(self):
         """Define default value for datetime fields."""
@@ -302,6 +299,14 @@ class DatasetFile(Entity):
         self._id = self.default_id()
         self._label = self.default_label()
 
+    def update_metadata(self, path, commit):
+        """Update files metadata."""
+        self.path = str((self.client.path / path).relative_to(self.client.path))
+        self.update_commit(commit)
+        self.filename = self.default_filename()
+        self.url = self.default_url()
+        self.added = self._now()
+
     @classmethod
     def from_jsonld(cls, data):
         """Create an instance from JSON-LD data."""
@@ -523,6 +528,9 @@ class Dataset(Entity, CreatorMixin):
 
     def update_files(self, files):
         """Update files with collection of DatasetFile objects."""
+        if isinstance(files, DatasetFile):
+            files = (files,)
+
         new_files = []
 
         for new_file in files:
@@ -539,22 +547,7 @@ class Dataset(Entity, CreatorMixin):
         self._modified = True
         self.files += new_files
 
-        self._update_files_metadata()
-
-    def rename_files(self, rename):
-        """Rename files using the path mapping function."""
-        files = []
-
-        for file_ in self.files:
-            self._modified = True
-            new_path = rename(file_.path)
-            new_file = attr.evolve(file_, path=new_path)
-            if not self.find_file(new_file.path):
-                files.append(new_file)
-            else:
-                raise errors.InvalidFileOperation(f"Destination file already exists: {new_file.path}")
-
-        self.files = files
+        self._update_files_metadata(new_files)
 
     def unlink_file(self, path, missing_ok=False):
         """Unlink a file from dataset.
@@ -653,25 +646,19 @@ class Dataset(Entity, CreatorMixin):
         if not self.name:
             self.name = generate_default_name(self.title, self.version)
 
-    def _update_files_metadata(self):
-        if not self.files or not self.client:
+    def _update_files_metadata(self, files=None):
+        files = files or self.files
+
+        if not files or not self.client:
             return
 
-        paths = [f.path for f in self.files]
-        attrs = self.client.find_attr(*paths)
-
-        for file_ in self.files:
-            path = Path(file_.path)
-            file_exists = path.exists() or (path.is_symlink() and os.path.lexists(path))
+        for file_ in files:
+            path = self.client.path / file_.path
+            file_exists = path.exists() or path.is_symlink()
 
             if not file_exists:
                 continue
 
-            if attrs.get(str(path), {}).get("filter") == "lfs":
-                file_.is_lfs = True
-            else:
-                file_.is_lfs = False
-
             if file_.client is None:
                 client, _, _ = self.client.resolve_in_submodules(
                     self.client.find_previous_commit(file_.path, revision="HEAD"), file_.path,
@@ -911,19 +898,6 @@ def generate_default_name(dataset_title, dataset_version=None):
     return name
 
 
-def get_slug(name):
-    """Create a slug from name."""
-    lower_case = name.lower()
-    no_space = re.sub(r"\s+", "_", lower_case)
-    normalized = unicodedata.normalize("NFKD", no_space).encode("ascii", "ignore").decode("utf-8")
-    no_invalid_characters = re.sub(r"[^a-zA-Z0-9._-]", "_", normalized)
-    no_duplicates = re.sub(r"([._-])[._-]+", r"\1", no_invalid_characters)
-    valid_start = re.sub(r"^[._-]", "", no_duplicates)
-    valid_end = re.sub(r"[._-]$", "", valid_start)
-    no_dot_lock_at_end = re.sub(r"\.lock$", "_lock", valid_end)
-    return no_dot_lock_at_end
-
-
 def generate_url_id(client, url_str, url_id):
     """Generate @id field for Url."""
     if url_str:
@@ -1018,3 +992,19 @@ class DatasetDetailsJson(marshmallow.Schema):
     description = marshmallow.fields.String()
     keywords = marshmallow.fields.List(marshmallow.fields.String())
     identifier = marshmallow.fields.String()
+
+
+class DatasetFileDetailsJson(marshmallow.Schema):
+    """Serialize dataset files to a response object."""
+
+    path = marshmallow.fields.String()
+    created = marshmallow.fields.DateTime()
+    added = marshmallow.fields.DateTime()
+
+    size = marshmallow.fields.String()
+    is_lfs = marshmallow.fields.Boolean()
+
+    dataset_id = marshmallow.fields.String()
+    dataset_name = marshmallow.fields.String()
+
+    creators = marshmallow.fields.List(marshmallow.fields.Nested(DatasetCreatorsJson))
