@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2018-2020- Swiss Data Science Center (SDSC)
+# Copyright 2018-2021- Swiss Data Science Center (SDSC)
 # A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
 # Eidgenössische Technische Hochschule Zürich (ETHZ).
 #
@@ -49,7 +49,7 @@ class Person:
 
     def default_id(self):
         """Set the default id."""
-        return generate_person_id(email=self.email, client=self.client)
+        return generate_person_id(email=self.email, client=self.client, full_identity=self.full_identity)
 
     @email.validator
     def check_email(self, attribute, value):
@@ -124,7 +124,7 @@ class Person:
     def __attrs_post_init__(self):
         """Finish object initialization."""
         # handle the case where ids were improperly set
-        if self._id == "mailto:None" or self._id is None:
+        if self._id == "mailto:None" or not self._id or self._id.startswith("_:"):
             self._id = self.default_id()
 
         if self.label is None:
@@ -141,11 +141,11 @@ class PersonSchema(JsonLDSchema):
         model = Person
         unknown = EXCLUDE
 
-    name = StringList(schema.name, fields.String(), missing=None)
+    name = StringList(schema.name, missing=None)
     email = fields.String(schema.email, missing=None)
-    label = StringList(rdfs.label, fields.String(), missing=None)
-    affiliation = StringList(schema.affiliation, fields.String(), missing=None)
-    alternate_name = StringList(schema.alternateName, fields.String(), missing=None)
+    label = StringList(rdfs.label, missing=None)
+    affiliation = StringList(schema.affiliation, missing=None)
+    alternate_name = StringList(schema.alternateName, missing=None)
     _id = fields.Id(init_name="id")
 
 
@@ -187,7 +187,7 @@ class SoftwareAgent:
 renku_agent = SoftwareAgent(label="renku {0}".format(__version__), id=version_url)
 
 
-def generate_person_id(email, client=None):
+def generate_person_id(client, email, full_identity):
     """Generate Person default id."""
     if email:
         return "mailto:{email}".format(email=email)
@@ -197,7 +197,7 @@ def generate_person_id(email, client=None):
         host = client.remote.get("host") or host
     host = os.environ.get("RENKU_DOMAIN") or host
 
-    id_ = str(uuid.uuid4())
+    id_ = full_identity or str(uuid.uuid4())
 
     return urllib.parse.urljoin(
         "https://{host}".format(host=host), pathlib.posixpath.join("/persons", quote(id_, safe=""))
