@@ -17,10 +17,10 @@
 # limitations under the License.
 """Version information for Renku."""
 
-__version__ = '0.14.1'
+__version__ = '0.15.0'
 
 
-def _get_disribution_url():
+def _get_distribution_url():
     try:
         import pkg_resources
         d = pkg_resources.get_distribution('renku')
@@ -31,4 +31,4 @@ def _get_disribution_url():
         return 'N/A'
 
 
-version_url = '{}/tree/{}'.format(_get_disribution_url(), 'v' + __version__)
+version_url = '{}/tree/{}'.format(_get_distribution_url(), 'v' + __version__)
