@@ -30,9 +30,10 @@ from renku.core import errors
 from renku.core.commands.dataset import add_to_dataset, create_dataset, file_unlink, list_datasets, list_files
 from renku.core.errors import OperationError, ParameterError
 from renku.core.management.repository import DEFAULT_DATA_DIR as DATA_DIR
-from renku.core.models.datasets import Dataset, get_slug
+from renku.core.models.datasets import Dataset
 from renku.core.models.provenance.agents import Person
 from renku.core.utils.contexts import chdir
+from renku.core.utils.urls import get_slug
 from tests.utils import assert_dataset_is_mutated, raises
 
 
