@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2018-2020- Swiss Data Science Center (SDSC)
+# Copyright 2018-2021- Swiss Data Science Center (SDSC)
 # A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
 # Eidgenössische Technische Hochschule Zürich (ETHZ).
 #
@@ -17,6 +17,8 @@
 # limitations under the License.
 """Git regex tests."""
 
+import os
+
 import pytest
 
 from renku.core import errors
@@ -66,20 +68,29 @@ from renku.core.models.git import GitURL
             "port": "1234",
         },
         {
-            "href": "https://example.com:1234/prefix/owner/repo.git",
+            "href": "https://example.com:1234/gitlab/owner/repo.git",
             "protocol": "https",
             "hostname": "example.com",
             "name": "repo",
-            "pathname": "prefix/owner/repo.git",
+            "pathname": "gitlab/owner/repo.git",
             "owner": "owner",
             "port": "1234",
         },
         {
-            "href": "https://example.com/pre.fix/owner.name/repo.name.git",
+            "href": "https://example.com:1234/gitlab/group/owner/repo.git",
             "protocol": "https",
             "hostname": "example.com",
-            "pathname": "pre.fix/owner.name/repo.name.git",
-            "owner": "owner.name",
+            "name": "repo",
+            "pathname": "gitlab/group/owner/repo.git",
+            "owner": "group/owner",
+            "port": "1234",
+        },
+        {
+            "href": "https://example.com/gro.up/owner.name/repo.name.git",
+            "protocol": "https",
+            "hostname": "example.com",
+            "pathname": "gro.up/owner.name/repo.name.git",
+            "owner": "gro.up/owner.name",
             "name": "repo.name",
         },
         {
@@ -167,7 +178,7 @@ from renku.core.models.git import GitURL
             "hostname": "example.com",
             "name": "repo",
             "pathname": "prefix/owner/repo.git",
-            "owner": "owner",
+            "owner": "prefix/owner",
             "username": "git",
         },
         {"href": "/path/to/repo", "pathname": "/path/to/repo",},
@@ -216,11 +227,64 @@ from renku.core.models.git import GitURL
             "hostname": "example.com",
             "name": "repo",
             "pathname": "1234/prefix/owner/repo.git",
+            "owner": "1234/prefix/owner",
+        },
+        {
+            "href": "https://example.com:1234/gitlab/owner/repo.git",
+            "protocol": "https",
+            "hostname": "example.com",
+            "name": "repo",
+            "pathname": "gitlab/owner/repo.git",
             "owner": "owner",
+            "port": "1234",
+            "env": "https://example.com:1234/gitlab/",
+        },
+        {
+            "href": "https://example.com:1234/gitlab/owner/repo.git",
+            "protocol": "https",
+            "hostname": "example.com",
+            "name": "repo",
+            "pathname": "gitlab/owner/repo.git",
+            "owner": "owner",
+            "port": "1234",
+            "env": "https://example.com/gitlab/",
+        },
+        {
+            "href": "https://example.com/gitlab/owner/repo.git",
+            "protocol": "https",
+            "hostname": "example.com",
+            "name": "repo",
+            "pathname": "gitlab/owner/repo.git",
+            "owner": "owner",
+            "env": "https://example.com/gitlab/",
+        },
+        {
+            "href": "https://gitlab.example.com/owner/repo.git",
+            "protocol": "https",
+            "hostname": "gitlab.example.com",
+            "name": "repo",
+            "pathname": "owner/repo.git",
+            "owner": "owner",
+            "env": "https://gitlab.example.com/",
+        },
+        {
+            "href": "https://gitlab.example.com:1234/owner/repo.git",
+            "protocol": "https",
+            "hostname": "gitlab.example.com",
+            "name": "repo",
+            "pathname": "owner/repo.git",
+            "owner": "owner",
+            "port": "1234",
+            "env": "https://gitlab.example.com:1234/",
         },
     ],
 )
 def test_valid_href(fields):
     """Test the various repo regexes."""
     fields.pop("protocols", None)
+    gitlab_env = fields.pop("env", None)
+
+    if gitlab_env:
+        os.environ["GITLAB_BASE_URL"] = gitlab_env
+
     assert GitURL(**fields) == GitURL.parse(fields["href"])
