@@ -59,7 +59,6 @@ def test_create_dataset_view(svc_client_with_repo):
     }
 
     response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
-
     assert response
     assert_rpc_response(response)
 
@@ -67,6 +66,44 @@ def test_create_dataset_view(svc_client_with_repo):
     assert payload["name"] == response.json["result"]["name"]
 
 
+@pytest.mark.service
+@pytest.mark.integration
+@flaky(max_runs=30, min_passes=1)
+def test_remote_create_dataset_view(svc_client_cache, it_remote_repo_url):
+    """Create a new dataset successfully."""
+    svc_client, headers, cache = svc_client_cache
+
+    payload = {
+        "git_url": it_remote_repo_url,
+        "name": "{0}".format(uuid.uuid4().hex),
+    }
+
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    assert response
+    assert_rpc_response(response, with_key="error")
+    assert {"code", "migration_required", "reason"} == set(response.json["error"].keys())
+
+
+@pytest.mark.service
+@pytest.mark.integration
+@flaky(max_runs=30, min_passes=1)
+def test_delay_create_dataset_view(svc_client_cache, it_remote_repo_url):
+    """Create a new job for dataset create operation."""
+    svc_client, headers, cache = svc_client_cache
+
+    payload = {
+        "git_url": it_remote_repo_url,
+        "name": "{0}".format(uuid.uuid4().hex),
+        "is_delayed": True,
+    }
+
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+
+    assert response
+    assert_rpc_response(response, with_key="result")
+    assert {"job_id", "created_at"} == set(response.json["result"].keys())
+
+
 @pytest.mark.service
 @pytest.mark.integration
 @flaky(max_runs=30, min_passes=1)
@@ -82,7 +119,9 @@ def test_create_dataset_wrong_ref_view(svc_client_with_repo):
     response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
 
     assert response
-    assert {"error": {"code": -32100, "reason": 'project_id "ref does not exist" not found'}} == response.json
+    assert {
+        "error": {"code": RENKU_EXCEPTION_ERROR_CODE, "reason": 'project_id "ref does not exist" not found'}
+    } == response.json
 
 
 @pytest.mark.service
@@ -113,6 +152,22 @@ def test_remove_dataset_view(svc_client_with_repo):
     assert payload["name"] not in datasets
 
 
+@pytest.mark.integration
+@pytest.mark.service
+@flaky(max_runs=30, min_passes=1)
+def test_remote_remove_view(svc_client, it_remote_repo_url, identity_headers):
+    """Test creating a delayed remove."""
+    response = svc_client.post(
+        "/datasets.remove",
+        data=json.dumps(dict(git_url=it_remote_repo_url, is_delayed=True, name="mydata")),
+        headers=identity_headers,
+    )
+
+    assert 200 == response.status_code
+    assert response.json["result"]["created_at"]
+    assert response.json["result"]["job_id"]
+
+
 @pytest.mark.service
 @pytest.mark.integration
 @flaky(max_runs=30, min_passes=1)
@@ -532,7 +587,7 @@ def test_add_file_view(svc_client_with_repo):
         "project_id": project_id,
         "name": uuid.uuid4().hex,
         "create_dataset": True,
-        "files": [{"file_id": file_id,},],
+        "files": [{"file_id": file_id}],
     }
     headers["Content-Type"] = content_type
 
@@ -584,6 +639,24 @@ def test_add_file_commit_msg(svc_client_with_repo):
     assert file_id == response.json["result"]["files"][0]["file_id"]
 
 
+@pytest.mark.integration
+@pytest.mark.service
+@flaky(max_runs=30, min_passes=1)
+def test_remote_add_view(svc_client, it_remote_repo_url, identity_headers):
+    """Test creating a delayed add."""
+    response = svc_client.post(
+        "/datasets.add",
+        data=json.dumps(
+            dict(git_url=it_remote_repo_url, is_delayed=True, name="mydata", files=[{"file_path": "somefile.txt"}])
+        ),
+        headers=identity_headers,
+    )
+
+    assert 200 == response.status_code
+    assert response.json["result"]["created_at"]
+    assert response.json["result"]["job_id"]
+
+
 @pytest.mark.service
 @pytest.mark.integration
 @flaky(max_runs=30, min_passes=1)
@@ -607,7 +680,7 @@ def test_add_file_failure(svc_client_with_repo):
         "project_id": project_id,
         "name": uuid.uuid4().hex,
         "create_dataset": True,
-        "files": [{"file_id": file_id,}, {"file_path": "my problem right here"}],
+        "files": [{"file_id": file_id}, {"file_path": "my problem right here"}],
     }
     headers["Content-Type"] = content_type
     response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
@@ -792,6 +865,22 @@ def test_list_datasets_files_remote(svc_client_with_repo, it_remote_repo_url):
     assert "ds1" == response.json["result"]["name"]
 
 
+@pytest.mark.integration
+@pytest.mark.service
+@flaky(max_runs=30, min_passes=1)
+def test_remote_create_view(svc_client, it_remote_repo_url, identity_headers):
+    """Test creating a delayed dataset create."""
+    response = svc_client.post(
+        "/datasets.create",
+        data=json.dumps(dict(git_url=it_remote_repo_url, is_delayed=True, name=uuid.uuid4().hex,)),
+        headers=identity_headers,
+    )
+
+    assert 200 == response.status_code
+    assert response.json["result"]["created_at"]
+    assert response.json["result"]["job_id"]
+
+
 @pytest.mark.service
 @pytest.mark.integration
 @flaky(max_runs=10, min_passes=1)
@@ -1086,7 +1175,7 @@ def test_add_existing_file(svc_client_with_repo):
 @pytest.mark.integration
 @pytest.mark.service
 @flaky(max_runs=30, min_passes=1)
-def test_import_dataset_job_enqueue(doi, svc_client_cache, project):
+def test_cached_import_dataset_job(doi, svc_client_cache, project):
     """Test import a dataset."""
     client, headers, cache = svc_client_cache
 
@@ -1113,7 +1202,7 @@ def test_import_dataset_job_enqueue(doi, svc_client_cache, project):
 
     response = client.post(
         "/datasets.import",
-        data=json.dumps({"project_id": project_meta["project_id"], "dataset_uri": doi,}),
+        data=json.dumps({"project_id": project_meta["project_id"], "dataset_uri": doi}),
         headers=headers,
     )
 
@@ -1130,6 +1219,25 @@ def test_import_dataset_job_enqueue(doi, svc_client_cache, project):
     assert user_job.job_id in [job["job_id"] for job in response.json["result"]["jobs"]]
 
 
+@pytest.mark.parametrize(
+    "doi", ["10.5281/zenodo.3239980",],
+)
+@pytest.mark.integration
+@pytest.mark.service
+@flaky(max_runs=30, min_passes=1)
+def test_remote_import_dataset_job(doi, svc_client, it_remote_repo_url, identity_headers):
+    """Test creating a delayed import of a dataset."""
+    response = svc_client.post(
+        "/datasets.import",
+        data=json.dumps(dict(git_url=it_remote_repo_url, dataset_uri=doi, is_delayed=True,)),
+        headers=identity_headers,
+    )
+
+    assert 200 == response.status_code
+    assert response.json["result"]["created_at"]
+    assert response.json["result"]["job_id"]
+
+
 @pytest.mark.parametrize("url", ["https://gist.github.com/jsam/d957f306ed0fe4ff018e902df6a1c8e3"])
 @pytest.mark.integration
 @pytest.mark.service
@@ -1451,6 +1559,22 @@ def test_edit_dataset_with_images(svc_client_with_repo):
     assert 0 == len(response.json["result"]["edited"].keys())
 
 
+@pytest.mark.integration
+@pytest.mark.service
+@flaky(max_runs=30, min_passes=1)
+def test_remote_edit_view(svc_client, it_remote_repo_url, identity_headers):
+    """Test creating a delayed edit."""
+    response = svc_client.post(
+        "/datasets.edit",
+        data=json.dumps(dict(git_url=it_remote_repo_url, is_delayed=True, name="mydata")),
+        headers=identity_headers,
+    )
+
+    assert 200 == response.status_code
+    assert response.json["result"]["created_at"]
+    assert response.json["result"]["job_id"]
+
+
 @pytest.mark.integration
 @flaky(max_runs=10, min_passes=1)
 def test_protected_branch(svc_protected_repo):
@@ -1478,14 +1602,30 @@ def test_protected_branch(svc_protected_repo):
 def test_unlink_file(unlink_file_setup):
     """Check unlinking of a file from a dataset."""
     svc_client, headers, unlink_payload = unlink_file_setup
+    response = svc_client.post("/datasets.unlink", data=json.dumps(unlink_payload), headers=headers)
 
-    response = svc_client.post("/datasets.unlink", data=json.dumps(unlink_payload), headers=headers,)
     assert_rpc_response(response, with_key="result")
 
     assert {"unlinked", "remote_branch"} == set(response.json["result"].keys())
     assert ["README.md"] == response.json["result"]["unlinked"]
 
 
+@pytest.mark.integration
+@pytest.mark.service
+@flaky(max_runs=30, min_passes=1)
+def test_remote_unlink_view(svc_client, it_remote_repo_url, identity_headers):
+    """Test creating a delayed unlink."""
+    response = svc_client.post(
+        "/datasets.unlink",
+        data=json.dumps(dict(git_url=it_remote_repo_url, is_delayed=True, name="mydata", include_filters=["data1"])),
+        headers=identity_headers,
+    )
+
+    assert 200 == response.status_code
+    assert response.json["result"]["created_at"]
+    assert response.json["result"]["job_id"]
+
+
 @pytest.mark.integration
 @pytest.mark.service
 @flaky(max_runs=10, min_passes=1)
@@ -1510,4 +1650,6 @@ def test_unlink_file_exclude(unlink_file_setup):
 
     response = svc_client.post("/datasets.unlink", data=json.dumps(unlink_payload), headers=headers,)
 
-    assert {"error": {"code": -32100, "reason": "Invalid parameter value - No records found."}} == response.json
+    assert {
+        "error": {"code": RENKU_EXCEPTION_ERROR_CODE, "reason": "Invalid parameter value - No records found."}
+    } == response.json
