@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2019-2020 - Swiss Data Science Center (SDSC)
+# Copyright 2019-2021 - Swiss Data Science Center (SDSC)
 # A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
 # Eidgenössische Technische Hochschule Zürich (ETHZ).
 #
@@ -17,11 +17,17 @@
 # limitations under the License.
 """Renku service jobs view tests."""
 import copy
+import time
 import uuid
 from datetime import datetime
 
+import jwt
 import pytest
 from marshmallow.utils import isoformat
+from werkzeug.utils import secure_filename
+
+from renku.service.cache.models.project import Project
+from renku.service.serializers.headers import JWT_TOKEN_SECRET, encode_b64
 
 
 @pytest.mark.service
@@ -34,14 +40,13 @@ def test_jobs_view_identity_protected(svc_client):
     response = svc_client.get("/jobs", headers=headers)
 
     assert {"error"} == set(response.json.keys())
-    assert ("user identification is incorrect or missing") == response.json["error"]["reason"]
+    assert "user identification is incorrect or missing" == response.json["error"]["reason"]
 
 
 @pytest.mark.service
-def test_jobs_view_empty_result(svc_client):
+def test_jobs_view_empty_result(svc_client, identity_headers):
     """Check empty result for user requested jobs."""
-    headers = {"Content-Type": "application/json", "accept": "application/json", "Renku-User-Id": "user"}
-    response = svc_client.get("/jobs", headers=headers)
+    response = svc_client.get("/jobs", headers=identity_headers)
 
     assert {"result"} == set(response.json.keys())
     assert [] == response.json["result"]["jobs"]
@@ -52,19 +57,29 @@ def test_jobs_view_expected_job(svc_client_cache):
     """Check non-empty result for user requested job."""
     svc_client, headers, cache = svc_client_cache
 
-    user = cache.ensure_user({"user_id": "user"})
+    user_id = encode_b64(secure_filename("9ab2fc80-3a5c-426d-ae78-56de01d214df"))
+    user = cache.ensure_user({"user_id": user_id})
+
     job_data = {
         "job_id": uuid.uuid4().hex,
         "state": "CREATED",
+        "renku_op": "dataset_import",
         "created_at": isoformat(datetime.now()),
         "updated_at": isoformat(datetime.now()),
         "extras": {"progress": 42},
     }
-    job = cache.make_job(user, job_data)
+
+    project = Project(project_id="123", user_id=user.user_id, owner="renkumeister", name="testproject")
+    project.abs_path.mkdir(parents=True, exist_ok=True)
+    project.save()
+
+    job = cache.make_job(user, project=project, job_data=job_data)
 
     response = svc_client.get("/jobs", headers=headers)
     assert 1 == len(response.json["result"]["jobs"])
-    assert {"job_id", "state", "created_at", "updated_at", "extras",} == set(response.json["result"]["jobs"][0].keys())
+    assert {"job_id", "state", "created_at", "updated_at", "extras", "client_extras", "renku_op", "project"} == set(
+        response.json["result"]["jobs"][0].keys()
+    )
 
     cache.invalidate_job(user, job.job_id)
     response = svc_client.get("/jobs", headers=headers)
@@ -76,7 +91,8 @@ def test_jobs_view_check_exclusion(svc_client_cache):
     """Check non-empty result for user requested jobs."""
     svc_client, headers, cache = svc_client_cache
 
-    user = cache.ensure_user({"user_id": "user"})
+    user_id = encode_b64(secure_filename("9ab2fc80-3a5c-426d-ae78-56de01d214df"))
+    user = cache.ensure_user({"user_id": user_id})
     excluded_user = cache.ensure_user({"user_id": "excluded_user"})
 
     for _ in range(10):
@@ -86,14 +102,20 @@ def test_jobs_view_check_exclusion(svc_client_cache):
             "created_at": isoformat(datetime.utcnow()),
             "updated_at": isoformat(datetime.utcnow()),
             "extras": {"progress": 42},
+            "renku_op": "dataset_import",
         }
-        job1 = cache.make_job(user, job_data)
+
+        project = Project(project_id="123", user_id=user.user_id, owner="renkumeister", name="testproject")
+        project.abs_path.mkdir(parents=True, exist_ok=True)
+        project.save()
+
+        job1 = cache.make_job(user, project=project, job_data=job_data)
         assert job1
 
         new_job = copy.deepcopy(job_data)
         new_job["job_id"] = uuid.uuid4().hex
 
-        job2 = cache.make_job(excluded_user, new_job)
+        job2 = cache.make_job(excluded_user, project=project, job_data=new_job)
         assert job2
 
         assert job1.job_id != job2.job_id
@@ -103,7 +125,9 @@ def test_jobs_view_check_exclusion(svc_client_cache):
     assert {"result"} == set(response.json.keys())
     assert 10 == len(response.json["result"]["jobs"])
     for job in response.json["result"]["jobs"]:
-        assert {"job_id", "state", "created_at", "updated_at", "extras"} == set(job.keys())
+        assert {"job_id", "state", "created_at", "updated_at", "extras", "client_extras", "renku_op", "project"} == set(
+            job.keys()
+        )
 
 
 @pytest.mark.service
@@ -116,25 +140,23 @@ def test_job_details_auth(svc_client):
     response = svc_client.get("/jobs/myjob", headers=headers)
 
     assert {"error"} == set(response.json.keys())
-    assert ("user identification is incorrect or missing") == response.json["error"]["reason"]
+    assert "user identification is incorrect or missing" == response.json["error"]["reason"]
 
 
 @pytest.mark.service
-def test_job_details_empty(svc_client):
+def test_job_details_empty(svc_client, identity_headers):
     """Check job details for a user."""
-    headers = {"Content-Type": "application/json", "accept": "application/json", "Renku-User-Id": "user"}
-    response = svc_client.get("/jobs/myjob", headers=headers)
+    response = svc_client.get("/jobs/myjob", headers=identity_headers)
 
     assert {"result"} == set(response.json.keys())
     assert response.json["result"] is None
 
 
 @pytest.mark.service
-def test_job_details_2user(svc_client_cache):
+def test_job_details_by_user(svc_client_with_user):
     """Check job details for a user."""
-    svc_client, headers, cache = svc_client_cache
+    svc_client, headers, cache, user = svc_client_with_user
 
-    user = cache.ensure_user({"user_id": "user"})
     jobs = [
         {
             "job_id": uuid.uuid4().hex,
@@ -142,19 +164,48 @@ def test_job_details_2user(svc_client_cache):
             "created_at": isoformat(datetime.now()),
             "updated_at": isoformat(datetime.now()),
             "extras": {"progress": 42},
+            "renku_op": "dataset_import",
         }
         for _ in range(10)
     ]
 
-    for job_data in jobs:
-        cache.make_job(user, job_data)
+    project = Project(project_id="123", user_id=user.user_id, owner="renkumeister", name="testproject")
+    project.abs_path.mkdir(parents=True, exist_ok=True)
+    project.save()
 
-    user_headers = copy.deepcopy(headers)
-    headers["Renku-User-Id"] = "excluded_user"
-    excluded_user_headers = copy.deepcopy(headers)
+    for job_data in jobs:
+        cache.make_job(user, job_data=job_data, project=project)
+
+    jwt_data = {
+        "jti": "12345",
+        "exp": int(time.time()) + 1e6,
+        "nbf": 0,
+        "iat": 1595317694,
+        "iss": "https://stable.dev.renku.ch/auth/realms/Renku",
+        "aud": ["renku"],
+        "sub": "12345",
+        "typ": "ID",
+        "azp": "renku",
+        "nonce": "12345",
+        "auth_time": 1595317694,
+        "session_state": "12345",
+        "acr": "1",
+        "email_verified": False,
+        "preferred_username": "user1@platform2.com",
+        "given_name": "user",
+        "family_name": "user one",
+        "name": "User One",
+        "email": "user1@platform2.com",
+    }
+
+    excluded_user_headers = {
+        "Content-Type": "application/json",
+        "Renku-User": jwt.encode(jwt_data, JWT_TOKEN_SECRET, algorithm="HS256"),
+        "Authorization": headers["Authorization"],
+    }
 
     for job in jobs:
-        response = svc_client.get("/jobs/{0}".format(job["job_id"]), headers=user_headers)
+        response = svc_client.get("/jobs/{0}".format(job["job_id"]), headers=headers)
         assert response
         assert job["job_id"] == response.json["result"]["job_id"]
 
